#
# spec file for package python-pyjnius
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyjnius
Version:        1.5.0
Release:        1.1
Summary:        Access Java classes from Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/kivy/pyjnius
Source:         https://github.com/kivy/pyjnius/archive/%{version}.tar.gz#/pyjnius-%{version}.tar.gz
BuildRequires:  %{python_module Cython with %python-Cython < 3}
BuildRequires:  %{python_module setuptools}
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel
BuildRequires:  python-rpm-macros
Requires:       python-Cython
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  javapackages-local
# /SECTION
%python_subpackages

%description
Access Java classes from Python.

%prep
%setup -q -n pyjnius-%{version}
sed -i 's:python:python3:' tests/test_jvm_options.py

%build
export CFLAGS="%{optflags}"
%python_build
ant jar test-compile
mv build/test-classes tests

%install
%python_install
%{python_expand rm -f %{buildroot}%{$python_sitearch}/setup_sdist.py %{buildroot}%{$python_sitearch}/__pycache__/setup_sdist.*
%fdupes %{buildroot}%{$python_sitearch}
}

%check
mv jnius jnius.hide
%{python_expand export CLASSPATH="${PWD}/tests/test-classes:${PWD}/jnius.hide/src"
export PYTHONPATH=${PWD}:%{buildroot}%{$python_sitearch}
# https://github.com/kivy/pyjnius/issues/617
$python -m pytest -k 'not test_jvm_options'
}

%files %{python_files}
%doc README.md CHANGELOG.md
%license LICENSE
%{python_sitearch}/*

%changelog
* Sun Aug 13 2023 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  * Initialize logger as a child of the Kivy's one
  * Add support request automation (as other kivy projects)
  * Add support for Python 3.11
  * Remove Python 2 support, six dependency
  * Removes some Python2-era complexity
  * Remove Python 3.6 from supported and test matrix, as it
    reached EOL
- drop python-pyjnius-no-python2.patch (upstream)
* Tue Mar  7 2023 pgajdos@suse.com
- do not require python-six
- added patches
  fix https://github.com/kivy/pyjnius/commit/ee4e9c224c4a3dda1f15a6f161cd0dfb268eb0e3
  + python-pyjnius-no-python2.patch
* Wed Oct  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.4.2
  CI
  [#628] Updated java-setup to v3, include all the LTS versions from adoptium during CI tests.
  Packaging
  [#620] When cross-compiling for Android, we should not use the include dirs exposed by the JDK
  [#629] Cython now requires a minimum version. Introduces setup.cfg. Cleans up the CI workflow
  [#625] Use cibuildwheel for releases
  Docs
  [#616] Update api.rst, remove extra equals signs
  Implemented enhancements:
  [#622] Add suffix to support IBM jre on Windows
  [#626] Move get_cpu guessing into _possible_lib_location
  [#627] PyPy: Fixes a segfault + add tests
* Fri Feb 25 2022 pgajdos@suse.com
- version update to 1.4.1
  * *Implemented enhancements:**
  - [\#542](https://github.com/kivy/pyjnius/pull/542) Improve performance of byte array parameters
  - [\#515](https://github.com/kivy/pyjnius/pull/515) Allow passing Python Lambdas as Java lambdas
  - [\#541](https://github.com/kivy/pyjnius/pull/541) Refactor of env.py
  * *Fixed bugs:**
  - [\#549](https://github.com/kivy/pyjnius/pull/549) Fixes #548 JVM options are not correctly set by jnius_config.set_options()
  - [\#546](https://github.com/kivy/pyjnius/pull/546) Add in missing assignable check for int parameters etc.
  - [\#558](https://github.com/kivy/pyjnius/pull/558) Improve error message on method not found
  - [\#567](https://github.com/kivy/pyjnius/pull/567) Fix static methods
  - [\#566](https://github.com/kivy/pyjnius/pull/566) fix bug for constuctors with variable arguments
  - [\#569](https://github.com/kivy/pyjnius/pull/569) set_resolve_info: replace j_self w/ resolve_static
  - [\#595](https://github.com/kivy/pyjnius/pull/595) Use Python standard library `which` instead of OS `which`
  * *Documentation**
  - [\#556](https://github.com/kivy/pyjnius/pull/556) fix link in readme
  - [\#572](https://github.com/kivy/pyjnius/pull/572) update readme for python3
  - [\#584](https://github.com/kivy/pyjnius/pull/584) Updated android.rst for python3
  - [\#565](https://github.com/kivy/pyjnius/pull/565) Update python versions
* Mon Jan 25 2021 John Vandenberg <jayvdb@gmail.com>
- Skip Python 3.6 builds
* Sun Nov 15 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v1.3.0
- Active test suite
* Sat Apr 13 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.2.0
